% weighteddistance.m

% inputs: s1 and s2 (strings to test)
% ouput:  weightedd (weighted distance)

% algorithm
% compare each char
% if same, dist=0
% if diff, choose appropriate dist
% keep summing distance

function weightedd = weighteddistance(s1,s2)

% should put error check for s1 and s2

   if checkchars(s1) & checkchars(s2) & length(s1)==length(s2)

      % get substitution matrix sm
      % 
      if exist('subsmatrix.dat')
         sm = dlmread('subsmatrix.dat',' ');
      else
         error('No file subsmatix.dat found. Please create one.');
      end   
    
      % get indicies of string elements
      % these are the positions in the subs matrix (row or col) 
      % a=1, c=2, g=3, t=4
      ind1 = getindicies(s1);
      ind2 = getindicies(s2);

      % get distance
      % take each pair of indicies and extract weight from subs matrix
      weightedd = 0;
      for ii=1:length(s1)
    	 weightedd=weightedd + sm(ind1(ii),ind2(ii));
      end
 
   else
     error('Strings contain incorrect characters or have different legnths!');
   end
   
   
   
% inputs: v (valid DNA string)
% ouput: indicies (integer array containing substitution matrix indices
%                  for letter in corresponding position in string)
						
function indicies = getindicies(v)
   indicies=zeros(1,length(v));
   for ii=1:length(v)
      switch(v(ii))
      	case 'A',  indicies(ii)=1;   % A = 1
        case 'C',  indicies(ii)=2;   % C = 2
        case 'G',  indicies(ii)=3;   % G = 3
        case 'T',  indicies(ii)=4;   % T = 4
        otherwise, error('Warning: weighteddistance is messed up.');
      end
   end

   % could also use logical arrays here:
   % indicies = ones(1,length(v));
   % chars = ['A','C','G','T'];
   % for ii=1:length(chars)
   %     indicies(v==chars(ii))=ii;
   % end
